resultSet.SimpleResultSet

|  | ## Cheshire3 Object Model: Class SimpleResultSet

Module resultSet :: Class SimpleResultSet

## Class SimpleResultSet
source code

Object Tree:

    baseObjects.ResultSet --+
                            |
              RankedResultSet --+
                                |
                               SimpleResultSet

Known Subclasses:
  ArrayResultSet

Instance Methods

__init__(self, session, data=[], id="", recordStore="")
__getitem__(self, k)
__len__(self)
fromList(self, data)
serialise(self, session)
deserialise(self, session, data)
append(self, item)
extend(self, itemList)
_lrAssign(self, session, others, clause, cql, db)
_coriAssign(self, session, others, clause, cql, db)
_tfidfAssign(self, session, others, clause, cql, db)
combine(self, session, others, clause, db=None)
order(self, session, spec)
reverse(self, session)
retrieve(self, session, start, numReq, cache=0)
scale_weights(self)
Inherited from `RankedResultSet` (private): `_cmbzWeights`, `_meanWeights`, `_normWeights`, `_nprvWeights`, `_pivotWeights`, `_sumWeights` Inherited from `baseObjects.ResultSet`: `sort`

Class Variables

_list |
id |
termid |
totalOccs |
totalRecs |
expires |
index |
queryTerm |
queryFreq |
queryFragment |
queryPositions |
relevancy |
maxWeight |
minWeight |
termWeight |
recordStore |

Method Details

### __init__(self, session, data=[], id="", recordStore="") (Constructor) | source code

### __getitem__(self, k) (Indexing operator) | source code

### __len__(self) (Length operator) | source code

### fromList(self, data) | source code

### serialise(self, session) | source code

### deserialise(self, session, data) | source code

### append(self, item) | source code

### extend(self, itemList) | source code

### _lrAssign(self, session, others, clause, cql, db) | source code

### _coriAssign(self, session, others, clause, cql, db) | source code

### _tfidfAssign(self, session, others, clause, cql, db) | source code

### combine(self, session, others, clause, db=None) | source code
Overrides: baseObjects.ResultSet.combine

### order(self, session, spec) | source code

### reverse(self, session) | source code

### retrieve(self, session, start, numReq, cache=0) | source code
Overrides: baseObjects.ResultSet.retrieve

### scale_weights(self) | source code

Class Variable Details

    ### _list Value:
        []

    ### id Value:
        ''

    ### termid Value:
        -1

    ### totalOccs Value:
        0

    ### totalRecs Value:
        0

    ### expires Value:
        0

    ### index Value:
        None

    ### queryTerm Value:
        ''

    ### queryFreq Value:
        0

    ### queryFragment Value:
        None

    ### queryPositions Value:
        []

    ### relevancy Value:
        0

    ### maxWeight Value:
        0

    ### minWeight Value:
        0

    ### termWeight Value:
        0.0

    ### recordStore Value:
        ''